@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2004 Zope Corporation and Contributors.
+# Copyright (c) 2004 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -12,13 +12,24 @@
 #
 ##############################################################################
 """Tests for zope.localpermission.
-
-$Id$
 """
-import unittest
 import doctest
+import unittest
+
+from zope.testing.cleanup import CleanUp
+
+import zope.app.localpermission
+
+
+class TestConfiguration(CleanUp, unittest.TestCase):
+
+    def test_configuration(self):
+        from zope.configuration import xmlconfig
+        xmlconfig.file('configure.zcml', package=zope.app.localpermission)
+
 
 def test_suite():
     return unittest.TestSuite((
         doctest.DocTestSuite('zope.app.localpermission.permission'),
-        ))
+        unittest.defaultTestLoader.loadTestsFromName(__name__),
+    ))
